@@ -1,9 +1,17 @@
 ### This is a python package used for configuring a Morpheus appliance ###
 
-from .appliance import (
-   morpheusAppliance
+from .infra import (
+   groups
 )
 
+from . import (
+   appliance
+)
+
+# from .appliance import (
+#    morpheusAppliance
+# )
+
 # from .configs import (
 #     createMorpheusGroup,
 #     createMorpheusAwsCloud,
